==> haskell-xss-sanitize-0.3.5.7-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xss-sanitize
version: 0.3.5.7
id: xss-sanitize-0.3.5.7-EEMHUdw2GWzBMyVRZbuMpM
key: xss-sanitize-0.3.5.7-EEMHUdw2GWzBMyVRZbuMpM
license: BSD2
maintainer: Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://github.com/yesodweb/haskell-xss-sanitize
synopsis: sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details
category: Web
author: Greg Weber <greg@gregweber.info>
exposed: True
exposed-modules:
    Text.HTML.SanitizeXSS
hidden-modules: Text.HTML.SanitizeXSS.Css
abi: ea4184a3caa467f226bb8531f1bd1182
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/xss-sanitize-0.3.5.7
library-dirs: /usr/lib/ghc-8.0.1/site-local/xss-sanitize-0.3.5.7
data-dir: /usr/share/arm-linux-ghc-8.0.1/xss-sanitize-0.3.5.7
hs-libraries: HSxss-sanitize-0.3.5.7-EEMHUdw2GWzBMyVRZbuMpM
depends:
    attoparsec-0.13.1.0-2ptg9LSVcb1at70Z7RWD3 base-4.9.0.0
    containers-0.5.7.1 css-text-0.1.2.2-BPY3agNahq2DnjnAMKtSgU
    network-uri-2.6.1.0-FJ8JXDcVJz8KYX76kkCObd
    tagsoup-0.14.1-5UpYkVoOhOt4iyOyy0sWwj
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock
haddock-html: /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xss-sanitize-0.3.5.7-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xss-sanitize
version: 0.3.5.7
id: xss-sanitize-0.3.5.7-74u0N2jyPgSPXGlE9Nr4i
key: xss-sanitize-0.3.5.7-74u0N2jyPgSPXGlE9Nr4i
license: BSD2
maintainer: Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://github.com/yesodweb/haskell-xss-sanitize
synopsis: sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details
category: Web
author: Greg Weber <greg@gregweber.info>
exposed: True
exposed-modules:
    Text.HTML.SanitizeXSS
hidden-modules: Text.HTML.SanitizeXSS.Css
abi: 7f8e5ec90baa5bd7e8fe5a34150e7301
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/xss-sanitize-0.3.5.7
library-dirs: /usr/lib/ghc-8.0.1/site-local/xss-sanitize-0.3.5.7
data-dir: /usr/share/arm-linux-ghc-8.0.1/xss-sanitize-0.3.5.7
hs-libraries: HSxss-sanitize-0.3.5.7-74u0N2jyPgSPXGlE9Nr4i
depends:
    attoparsec-0.13.1.0-KaQFES0So1u93CSgT9OS1a base-4.9.0.0
    containers-0.5.7.1 css-text-0.1.2.2-3ynFDpBKQQa6qKPRLgpkAR
    network-uri-2.6.1.0-FJ8JXDcVJz8KYX76kkCObd
    tagsoup-0.14.1-5UpYkVoOhOt4iyOyy0sWwj
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock
haddock-html: /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
